@@ -4,24 +4,25 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-09-29'; # DATE
+our $DATE = '2022-09-25'; # DATE
 our $DIST = 'Sah-Schemas-ArrayData'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our $schema = [array => {
-    summary => 'Array of Perl ArrayData::* module names without the prefix, with optional args, e.g. ["Word::ID::KBBI", "WordList=wordlist,EN::Enable"]',
+    summary => 'Array of Perl ArrayData::* module names without the prefix, with optional args, e.g. ["Lingua::Word::ID::KBBI", "WordList=wordlist,EN::Enable"]',
     description => <<'_',
 
 Array of Perl ArrayData::* module names without the prefix and optional args.
-Each element is of `perl::arraydata::modname` schema, e.g. `Word::ID::KBBI`, `WordList=wordlist,EN::Enable`.
+Each element is of `perl::arraydata::modname` schema, e.g.
+`Lingua::Word::ID::KBBI`, `WordList=wordlist,EN::Enable`.
 
 Contains coercion rule that expands wildcard, so you can specify:
 
-    Word::ID::*
+    Lingua::Word::ID::*
 
 and it will be expanded to e.g.:
 
-    ["Word::ID::KBBI", "Word::ID::PERLANCAR"]
+    ["Lingua::Word::ID::KBBI", "Word::ID::PERLANCAR"]
 
 The wildcard syntax supports jokers (`?`, `*`, `**`), brackets (`[abc]`), and
 braces (`{one,two}`). See <pm:Module::List::Wildcard> for more details.
@@ -39,7 +40,7 @@ _
 }, {}];
 
 1;
-# ABSTRACT: Array of Perl ArrayData::* module names without the prefix, with optional args, e.g. ["Word::ID::KBBI", "WordList=wordlist,EN::Enable"]
+# ABSTRACT: Array of Perl ArrayData::* module names without the prefix, with optional args, e.g. ["Lingua::Word::ID::KBBI", "WordList=wordlist,EN::Enable"]
 
 __END__
 
@@ -49,24 +50,44 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::perl::arraydata::modnames_with_optional_args - Array of Perl ArrayData::* module names without the prefix, with optional args, e.g. ["Word::ID::KBBI", "WordList=wordlist,EN::Enable"]
+Sah::Schema::perl::arraydata::modnames_with_optional_args - Array of Perl ArrayData::* module names without the prefix, with optional args, e.g. ["Lingua::Word::ID::KBBI", "WordList=wordlist,EN::Enable"]
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schema::perl::arraydata::modnames_with_optional_args (from Perl distribution Sah-Schemas-ArrayData), released on 2021-09-29.
+This document describes version 0.003 of Sah::Schema::perl::arraydata::modnames_with_optional_args (from Perl distribution Sah-Schemas-ArrayData), released on 2022-09-25.
 
 =head1 SYNOPSIS
 
+=head2 Using with Data::Sah
+
 To check data against this schema (requires L<Data::Sah>):
 
  use Data::Sah qw(gen_validator);
  my $validator = gen_validator("perl::arraydata::modnames_with_optional_args*");
  say $validator->($data) ? "valid" : "INVALID!";
 
- # Data::Sah can also create validator that returns nice error message string
- # and/or coerced value. Data::Sah can even create validator that targets other
- # language, like JavaScript. All from the same schema. See its documentation
- # for more details.
+The above schema returns a boolean result (true if data is valid, false if
+otherwise). To return an error message string instead (empty string if data is
+valid, a non-empty error message otherwise):
+
+ my $validator = gen_validator("perl::arraydata::modnames_with_optional_args", {return_type=>'str_errmsg'});
+ my $errmsg = $validator->($data);
+
+Often a schema has coercion rule or default value, so after validation the
+validated value is different. To return the validated (set-as-default, coerced,
+prefiltered) value:
+
+ my $validator = gen_validator("perl::arraydata::modnames_with_optional_args", {return_type=>'str_errmsg+val'});
+ my $res = $validator->($data); # [$errmsg, $validated_val]
+
+Data::Sah can also create validator that returns a hash of detailed error
+message. Data::Sah can even create validator that targets other language, like
+JavaScript, from the same schema. Other things Data::Sah can do: show source
+code for validator, generate a validator code with debug comments and/or log
+statements, generate human text from schema. See its documentation for more
+details.
+
+=head2 Using with Params::Sah
 
 To validate function parameters against this schema (requires L<Params::Sah>):
 
@@ -79,11 +100,14 @@ To validate function parameters against this schema (requires L<Params::Sah>):
      ...
  }
 
+=head2 Using with Perinci::CmdLine::Lite
+
 To specify schema in L<Rinci> function metadata and use the metadata with
-L<Perinci::CmdLine> to create a CLI:
+L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
  # in lib/MyApp.pm
- package MyApp;
+ package
+   MyApp;
  our %SPEC;
  $SPEC{myfunc} = {
      v => 1.1,
@@ -103,9 +127,10 @@ L<Perinci::CmdLine> to create a CLI:
  1;
 
  # in myapp.pl
- package main;
+ package
+   main;
  use Perinci::CmdLine::Any;
- Perinci::CmdLine::Any->new(url=>'MyApp::myfunc')->run;
+ Perinci::CmdLine::Any->new(url=>'/MyApp/myfunc')->run;
 
  # in command-line
  % ./myapp.pl --help
@@ -119,15 +144,16 @@ L<Perinci::CmdLine> to create a CLI:
 =head1 DESCRIPTION
 
 Array of Perl ArrayData::* module names without the prefix and optional args.
-Each element is of C<perl::arraydata::modname> schema, e.g. C<Word::ID::KBBI>, C<WordList=wordlist,EN::Enable>.
+Each element is of C<perl::arraydata::modname> schema, e.g.
+C<Lingua::Word::ID::KBBI>, C<WordList=wordlist,EN::Enable>.
 
 Contains coercion rule that expands wildcard, so you can specify:
 
- Word::ID::*
+ Lingua::Word::ID::*
 
 and it will be expanded to e.g.:
 
- ["Word::ID::KBBI", "Word::ID::PERLANCAR"]
+ ["Lingua::Word::ID::KBBI", "Word::ID::PERLANCAR"]
 
 The wildcard syntax supports jokers (C<?>, C<*>, C<**>), brackets (C<[abc]>), and
 braces (C<{one,two}>). See L<Module::List::Wildcard> for more details.
@@ -157,13 +183,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2022, 2021 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
